<?php

/**
 * Classe plxFeed responsable du traitement global des flux de syndication
 *
 * @package PLX
 * @author	Florent MONTHEL
 **/
class plxFeed extends plxMotor {

	var $type = false; # Type de flux de syndication (rss ou atom)

	/**
	 * Constructeur qui initialise certaines variables de classe
	 * et qui lance le traitement initial
	 *
	 * @param	filename	emplacement du fichier XML de configuration
	 * @return	null
	 * @author	Florent MONTHEL
	 **/
	function plxFeed($filename) {
	
		$this->get = plxUtils::getGets();
		
		$this->getConfiguration($filename);
		$this->racine = $this->aConf['racine'];
		$this->bypage = $this->aConf['bypage_feed'];
		$this->tri = $this->aConf['tri'];
		
		$this->plxGlob_arts = & new plxGlob(PLX_ROOT.$this->aConf['racine_articles']);
		$this->plxGlob_coms = & new plxGlob(PLX_ROOT.$this->aConf['racine_commentaires']);
		
		$this->getCategories(PLX_ROOT.$this->aConf['categories']);
	}

	/**
	 * Méthode qui effectue une analyse de la situation et détermine 
	 * le mode à appliquer. Cette méthode alimente ensuite les variables 
	 * de classe adéquates
	 *
	 * @return	null
	 * @author	Florent MONTHEL
	 **/
	function prechauffage() {

		if($this->get AND preg_match('/^(atom|rss)$/',$this->get,$capture)) {
			$this->feed = $capture[1]; # Type de flux
			$this->mode = 'article'; # Mode du flux
			# On modifie le motif de recherche
			$this->motif = '/^[0-9]{4}.([0-9]{3}|home).[0-9]{12}.[a-z0-9-]+.xml$/';
		}
		elseif($this->get AND preg_match('/^(atom|rss)\/commentaires$/',$this->get,$capture)) {
			$this->feed = $capture[1]; # Type de flux
			$this->mode = 'commentaire'; # Mode du flux
		}
		elseif($this->get AND preg_match('/^(atom|rss)\/commentaires\/article([0-9]+$)/',$this->get,$capture)) {
			$this->feed = $capture[1]; # Type de flux
			$this->mode = 'commentaire'; # Mode du flux
			# On recupere l'article cible
			$this->cible = str_pad($capture[2],4,'0',STR_PAD_LEFT); # On complete sur 4 caracteres
			# On modifie le motif de recherche
			$this->motif = '/^'.$this->cible.'.([0-9]{3}|home).[0-9]{12}.[a-z0-9-]+.xml$/';
		} else {
			$this->feed = 'atom'; # Type de flux
			$this->mode = 'article'; # Mode du flux
			# On modifie le motif de recherche
			$this->motif = '/^[0-9]{4}.([0-9]{3}|home).[0-9]{12}.[a-z0-9-]+.xml$/';
		}
	}

	/**
	 * Méthode qui effectue le traitement selon le mode du moteur
	 *
	 * @return	null ou redirection si une erreur est détectée
	 * @author	Florent MONTHEL
	 **/	
	function demarrage() {

		if($this->mode == 'commentaire' AND $this->cible) { # Flux de commentaires d'un article precis
			$this->getFiles(); # Recuperation du fichier de l'article cible
			$this->getArticles(); # Recuperation de l'article cible (on le parse)
			if(!$this->plxGlob_arts->count OR !$this->plxRecord_arts->size) { # Aucun article, on redirige
				$this->cible = $this->cible + 0;
				header('Location: ./?article'.$this->cible.'/');
				exit;
			} else { # On récupère les commentaires
				$this->getCommentaires('/^'.$this->cible.'.[0-9]{10}-[0-9]+.xml$/','rsort',0,$this->bypage);
			}
		} elseif($this->mode == 'commentaire') { # Flux de commentaires global
			$this->getCommentaires('/^[0-9]{4}.[0-9]{10}-[0-9]+.xml$/','rsort',0,$this->bypage);
		} else { # Flux d'articles
			$this->getFiles(); # Recupération des fichier des articles
			$this->getArticles(); # Recupération des articles (on les parse)
		}
		
		# Selon le mode et le feed on appelle la méthode adéquate...
		switch($this->mode.'-'.$this->feed) {
			case 'article-atom' : $this->getAtomArticles(); break;
			case 'article-rss' : $this->getRssArticles(); break;
			case 'commentaire-atom' : $this->getAtomCommentaires(); break;
			case 'commentaire-rss' : $this->getRssCommentaires(); break;
			default : break;
		}
	}

	/**
	 * Méthode qui affiche le flux atom des articles du site
	 *
	 * @return	flux sur stdout
	 * @author	Florent MONTHEL
	 **/
	function getAtomArticles() {

		# Initialisation
		$last_updated = '';
		$entry = '';
		# On va boucler sur les articles (si il y'en a)
		if($this->plxRecord_arts) {
			while($this->plxRecord_arts->loop()) {
				# Traitement initial
				$content = $this->plxRecord_arts->f('chapo').$this->plxRecord_arts->f('content');
				$artId = $this->plxRecord_arts->f('numero') + 0;
				$catId = $this->plxRecord_arts->f('categorie');
				# On verifie que la categorie n'est pas "home"
				if($catId != 'home') {
					# On va verifier que la categorie existe
					if(isset($this->aCats[ $catId ]))
						$categorie = $this->aCats[ $catId ]['name'];
					else # La categorie n'existe pas
						$categorie = 'Non class&eacute;';
				} else { # Categorie "home"
					$categorie = 'Accueil';
				}
				# On check la date de publication
				if($this->plxRecord_arts->f('date') > $last_updated)
					$last_updated = $this->plxRecord_arts->f('date');
				# On affiche le flux dans un buffer
				$entry .= '<entry>'."\n";
				$entry .= "\t".'<title>'.htmlspecialchars($this->plxRecord_arts->f('title'),ENT_QUOTES,PLX_CHARSET).'</title> '."\n";
				$entry .= "\t".'<link href="'.$this->aConf['racine'].'?article'.$artId.'/'.$this->plxRecord_arts->f('url').'"/>'."\n";
				$entry .= "\t".'<id>urn:md5:'.md5($this->aConf['racine'].'?article'.$artId.'/'.$this->plxRecord_arts->f('url')).'</id>'."\n";
				$entry .= "\t".'<updated>'.$this->plxRecord_arts->f('date').'</updated>'."\n";
				$entry .= "\t".'<author><name>'.htmlspecialchars($this->plxRecord_arts->f('author'),ENT_QUOTES,PLX_CHARSET).'</name></author>'."\n";
				$entry .= "\t".'<dc:subject>'.htmlspecialchars($categorie,ENT_QUOTES,PLX_CHARSET).'</dc:subject>'."\n";
				$entry .= "\t".'<content type="html">'.htmlspecialchars($content,ENT_QUOTES,PLX_CHARSET).'</content>'."\n";
				$entry .= '</entry>'."\n";
			}
		}
		
		# On affiche le flux
		header ('Content-Type: text/xml; charset='.PLX_CHARSET);
		echo '<?xml version="1.0" encoding="'.PLX_CHARSET.'" ?>'."\n";
		echo '<feed xmlns="http://www.w3.org/2005/Atom" xmlns:dc="http://purl.org/dc/elements/1.1/">'."\n";
		echo '<title type="html">'.htmlspecialchars($this->aConf['title'],ENT_QUOTES,PLX_CHARSET).'</title>'."\n";
		echo '<subtitle type="html">'.htmlspecialchars($this->aConf['description'],ENT_QUOTES,PLX_CHARSET).'</subtitle>'."\n";
		echo '<link href="'.$this->aConf['racine'].'feed.php?atom" rel="self" type="application/atom+xml"/>'."\n";
		echo '<link href="'.$this->aConf['racine'].'" rel="alternate" type="text/html"/>'."\n";
		echo '<updated>'.$last_updated.'</updated>'."\n";
		echo '<id>urn:md5:'.md5($this->aConf['racine']).'</id>'."\n";
		echo '<generator uri="http://pluxml.org/">Pluxml '.$this->version.'</generator>'."\n";
		echo $entry;
		echo '</feed>';
	}

	/**
	 * Méthode qui affiche le flux rss des articles du site
	 *
	 * @return	flux sur stdout
	 * @author	Florent MONTHEL
	 **/
	function getRssArticles() {

		# Initialisation
		$last_updated = '';
		$entry_link = '';
		$entry = '';
		# On va boucler sur les articles (si il y'en a)
		if($this->plxRecord_arts) {
			while($this->plxRecord_arts->loop()) {
				# Traitement initial
				$content = $this->plxRecord_arts->f('chapo').$this->plxRecord_arts->f('content');
				$artId = $this->plxRecord_arts->f('numero') + 0;
				$catId = $this->plxRecord_arts->f('categorie');
				# On verifie que la categorie n'est pas "home"
				if($catId != 'home') {
					# On va verifier que la categorie existe
					if(isset($this->aCats[ $catId ]))
						$categorie = $this->aCats[ $catId ]['name'];
					else # La categorie n'existe pas
						$categorie = 'Non class&eacute;';
				} else { # Categorie "home"
					$categorie = 'Accueil';
				}
				# On check la date de publication
				if($this->plxRecord_arts->f('date') > $last_updated)
					$last_updated = $this->plxRecord_arts->f('date');
				# On affiche le résumé dans un buffer
				$entry_link .= "\t\t\t".'<rdf:li rdf:resource="'.$this->aConf['racine'].'?article'.$artId.'/'.$this->plxRecord_arts->f('url').'"/>'."\n";
				# On affiche le flux dans un buffer
				$entry .= '<item rdf:about="'.$this->aConf['racine'].'?article'.$artId.'/'.$this->plxRecord_arts->f('url').'">'."\n";
				$entry .= "\t".'<title>'.htmlspecialchars($this->plxRecord_arts->f('title'),ENT_QUOTES,PLX_CHARSET).'</title> '."\n";
				$entry .= "\t".'<link>'.$this->aConf['racine'].'?article'.$artId.'/'.$this->plxRecord_arts->f('url').'</link>'."\n";
				$entry .= "\t".'<dc:date>'.$this->plxRecord_arts->f('date').'</dc:date>'."\n";
				$entry .= "\t".'<dc:creator>'.htmlspecialchars($this->plxRecord_arts->f('author'),ENT_QUOTES,PLX_CHARSET).'</dc:creator>'."\n";
				$entry .= "\t".'<description>'.htmlspecialchars($content,ENT_QUOTES,PLX_CHARSET).'</description>'."\n";
				$entry .= '</item>'."\n";
			}
		}
		
		# On affiche le flux
		header ('Content-Type: text/xml; charset='.PLX_CHARSET);
		echo '<?xml version="1.0" encoding="'.PLX_CHARSET.'" ?>'."\n";
		echo '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns="http://purl.org/rss/1.0/">'."\n";
		echo '<channel rdf:about="'.$this->aConf['racine'].'">'."\n";
		echo "\t".'<title>'.htmlspecialchars($this->aConf['title'],ENT_QUOTES,PLX_CHARSET).'</title>'."\n";
		echo "\t".'<link>'.$this->aConf['racine'].'</link>'."\n";
		echo "\t".'<description>'.htmlspecialchars($this->aConf['description'],ENT_QUOTES,PLX_CHARSET).'</description>'."\n";
		echo "\t".'<lastBuildDate>'.$last_updated.'</lastBuildDate>'."\n";
		echo "\t".'<generator>Pluxml '.$this->version.'</generator>'."\n";
		echo "\t".'<dc:language>fr</dc:language>'."\n";
		echo  "\t".'<items>'."\n";
		echo "\t\t".'<rdf:Seq>'."\n";
		echo $entry_link;
		echo "\t\t".'</rdf:Seq>'."\n";
		echo "\t".'</items>'."\n";
		echo '</channel>'."\n";
		echo $entry;
		echo '</rdf:RDF>';
	}

	/**
	 * Méthode qui affiche le flux atom des commentaires du site
	 *
	 * @return	flux sur stdout
	 * @author	Florent MONTHEL
	 **/
	function getAtomCommentaires() {

		# Traitement initial
		$last_updated = '';
		$entry = '';
		if($this->cible) { # Commentaires d'un article
			$artId = $this->plxRecord_arts->f('numero') + 0;
			$title = $this->aConf['title'].' - '.$this->plxRecord_arts->f('title').' - Commentaires';
			$link = $this->aConf['racine'].'?article'.$artId.'/'.$this->plxRecord_arts->f('url');
			$link_feed = $this->aConf['racine'].'feed.php?atom/commentaires/article'.$artId;
		} else { # Commentaires globaux
			$title = $this->aConf['title'].' - Commentaires';
			$link = $this->aConf['racine'];
			$link_feed = $this->aConf['racine'].'feed.php?atom/commentaires';
		}
		
		# On va boucler sur les commentaires (si il y'en a)
		if($this->plxRecord_coms) {
			while($this->plxRecord_coms->loop()) {
				# Traitement initial
				$artId = $this->plxRecord_coms->f('article') + 0;
				if($this->cible) { # Commentaires d'un article
					$title_com = $this->plxRecord_arts->f('title').' - ';
					$title_com .= 'par '.$this->plxRecord_coms->f('author').' le ';
					$title_com .= plxUtils::dateIsoToHum($this->plxRecord_coms->f('date')).', ';
					$title_com .= plxUtils::heureIsoToHum($this->plxRecord_coms->f('date'));
					$link_com = $this->aConf['racine'].'?article'.$artId.'/'.$this->plxRecord_arts->f('url').'/#c'.$this->plxRecord_coms->f('numero');
				} else { # Commentaires globaux
					$title_com = $this->plxRecord_coms->f('author').' le ';
					$title_com .= plxUtils::dateIsoToHum($this->plxRecord_coms->f('date')).', ';
					$title_com .= plxUtils::heureIsoToHum($this->plxRecord_coms->f('date'));
					$link_com = $this->aConf['racine'].'?article'.$artId.'/#c'.$this->plxRecord_coms->f('numero');
				}
				# On check la date de publication
				if($this->plxRecord_coms->f('date') > $last_updated)
					$last_updated = $this->plxRecord_coms->f('date');
				# On affiche le flux dans un buffer
				$entry .= '<entry>'."\n";
				$entry .= "\t".'<title type="html">'.htmlspecialchars($title_com,ENT_QUOTES,PLX_CHARSET).'</title> '."\n";
				$entry .= "\t".'<link href="'.$link_com.'"/>'."\n";
				$entry .= "\t".'<id>urn:md5:'.md5($link_com).'</id>'."\n";
				$entry .= "\t".'<updated>'.$this->plxRecord_coms->f('date').'</updated>'."\n";
				$entry .= "\t".'<author><name>'.htmlspecialchars($this->plxRecord_coms->f('author'),ENT_QUOTES,PLX_CHARSET).'</name></author>'."\n";
				$entry .= "\t".'<content type="html">'.htmlspecialchars($this->plxRecord_coms->f('content'),ENT_QUOTES,PLX_CHARSET).'</content>'."\n";
				$entry .= '</entry>'."\n";
			}
		}
		
		# On affiche le flux
		header ('Content-Type: text/xml; charset='.PLX_CHARSET);
		echo '<?xml version="1.0" encoding="'.PLX_CHARSET.'" ?>'."\n";
		echo '<feed xmlns="http://www.w3.org/2005/Atom" xmlns:dc="http://purl.org/dc/elements/1.1/">'."\n";
		echo '<title type="html">'.htmlspecialchars($title,ENT_QUOTES,PLX_CHARSET).'</title>'."\n";
		echo '<subtitle type="html">'.htmlspecialchars($this->aConf['description'],ENT_QUOTES,PLX_CHARSET).'</subtitle>'."\n";
		echo '<link href="'.$link_feed.'" rel="self" type="application/atom+xml"/>'."\n";
		echo '<link href="'.$link.'" rel="alternate" type="text/html"/>'."\n";
		echo '<updated>'.$last_updated.'</updated>'."\n";
		echo '<id>urn:md5:'.md5($link).'</id>'."\n";
		echo '<generator uri="http://pluxml.org/">Pluxml '.$this->version.'</generator>'."\n";
		echo $entry;
		echo '</feed>';
	}

	/**
	 * Méthode qui affiche le flux rss des commentaires du site
	 *
	 * @return	flux sur stdout
	 * @author	Florent MONTHEL
	 **/
	function getRssCommentaires() {

		# Traitement initial
		$last_updated = '';
		$entry_link = '';
		$entry = '';
		if($this->cible) { # Commentaires d'un article
			$artId = $this->plxRecord_arts->f('numero') + 0;
			$title = $this->aConf['title'].' - '.$this->plxRecord_arts->f('title').' - Commentaires';
			$link = $this->aConf['racine'].'?article'.$artId.'/'.$this->plxRecord_arts->f('url');
		} else { # Commentaires globaux
			$title = $this->aConf['title'].' - Commentaires';
			$link = $this->aConf['racine'];
		}
		
		# On va boucler sur les commentaires (si il y'en a)
		if($this->plxRecord_coms) {
			while($this->plxRecord_coms->loop()) {
				# Traitement initial
				$artId = $this->plxRecord_coms->f('article') + 0;
				if($this->cible) { # Commentaires d'un article
					$title_com = $this->plxRecord_arts->f('title').' - ';
					$title_com .= 'par '.$this->plxRecord_coms->f('author').' le ';
					$title_com .= plxUtils::dateIsoToHum($this->plxRecord_coms->f('date')).', ';
					$title_com .= plxUtils::heureIsoToHum($this->plxRecord_coms->f('date'));
					$link_com = $this->aConf['racine'].'?article'.$artId.'/'.$this->plxRecord_arts->f('url').'/#c'.$this->plxRecord_coms->f('numero');
				} else { # Commentaires globaux
					$title_com = $this->plxRecord_coms->f('author').' le ';
					$title_com .= plxUtils::dateIsoToHum($this->plxRecord_coms->f('date')).', ';
					$title_com .= plxUtils::heureIsoToHum($this->plxRecord_coms->f('date'));
					$link_com = $this->aConf['racine'].'?article'.$artId.'/#c'.$this->plxRecord_coms->f('numero');
				}
				# On check la date de publication
				if($this->plxRecord_coms->f('date') > $last_updated)
					$last_updated = $this->plxRecord_coms->f('date');
				# On affiche le résumé dans un buffer
				$entry_link .= "\t\t\t".'<rdf:li rdf:resource="'.$link_com.'"/>'."\n";
				# On affiche le flux dans un buffer
				$entry .= '<item rdf:about="'.$link_com.'">'."\n";
				$entry .= "\t".'<title>'.htmlspecialchars($title_com,ENT_QUOTES,PLX_CHARSET).'</title> '."\n";
				$entry .= "\t".'<link>'.$link_com.'</link>'."\n";
				$entry .= "\t".'<dc:date>'.$this->plxRecord_coms->f('date').'</dc:date>'."\n";
				$entry .= "\t".'<dc:creator>'.htmlspecialchars($this->plxRecord_coms->f('author'),ENT_QUOTES,PLX_CHARSET).'</dc:creator>'."\n";
				$entry .= "\t".'<description>'.htmlspecialchars($this->plxRecord_coms->f('content'),ENT_QUOTES,PLX_CHARSET).'</description>'."\n";
				$entry .= '</item>'."\n";
			}
		}
		
		# On affiche le flux
		header ('Content-Type: text/xml; charset='.PLX_CHARSET);
		echo '<?xml version="1.0" encoding="'.PLX_CHARSET.'" ?>'."\n";
		echo '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns="http://purl.org/rss/1.0/">'."\n";
		echo '<channel rdf:about="'.$link.'">'."\n";
		echo "\t".'<title>'.htmlspecialchars($title,ENT_QUOTES,PLX_CHARSET).'</title>'."\n";
		echo "\t".'<link>'.$link.'</link>'."\n";
		echo "\t".'<description>'.htmlspecialchars($this->aConf['description'],ENT_QUOTES,PLX_CHARSET).'</description>'."\n";
		echo "\t".'<lastBuildDate>'.$last_updated.'</lastBuildDate>'."\n";
		echo "\t".'<generator>Pluxml '.$this->version.'</generator>'."\n";
		echo "\t".'<dc:language>fr</dc:language>'."\n";
		echo  "\t".'<items>'."\n";
		echo "\t\t".'<rdf:Seq>'."\n";
		echo $entry_link;
		echo "\t\t".'</rdf:Seq>'."\n";
		echo "\t".'</items>'."\n";
		echo '</channel>'."\n";
		echo $entry;
		echo '</rdf:RDF>';
	}

}
?>