<?php

/**
 * Classe plxMotor responsable du traitement global du script
 *
 * @package PLX
 * @author	Anthony GUÉRIN et Florent MONTHEL
 **/
class plxMotor {

	var $version = false; # Version de Pluxml
	var $start = false; # Microtime du debut de l'execution de Pluxml
	var $get = false; # Donnees variable GET
	var $racine = false; # Url de Pluxml
	var $style = false; # Dossier contenant le thème
	var $tri; # Tri d'affichage
	var $bypage = false; # Pagination
	var $page = 1; # Numéro de la page
	var $motif = false; # Motif de recherche
	var $mode = false; # Mode de traitement
	var $cible = false; # Article, categorie ou page statique cible
	var $message_com = false; # Message à la création d'un commentaire

	var $aConf = array(); # Tableau de configuration
	var $aCats = array(); # Tableau de toutes les catégories
	var $aStats = array(); # Tableau de toutes les pages statiques
	var $aFiles = array(); # Tableau de fichiers à traiter

	var $plxGlob_arts = null; # Objet plxGlob des articles
	var $plxGlob_coms = null; # Objet plxGlob des commentaires
	var $plxRecord_arts = null; # Objet plxRecord des articles
	var $plxRecord_coms = null; # Objet plxRecord des commentaires
	var $plxCapcha = null; # Objet plxCapcha
	var $plxErreur = null; # Objet plxErreur

	/**
	 * Constructeur qui initialise certaines variables de classe
	 * et qui lance le traitement initial
	 *
	 * @param	filename	emplacement du fichier XML de configuration
	 * @return	null
	 * @author	Anthony GUÉRIN et Florent MONTHEL
	 **/
	function plxMotor($filename) {

		# Version de Pluxml
		if(!is_readable(PLX_ROOT.'version')) {
			header('Content-Type: text/plain charset=UTF-8');
			echo 'Le fichier "'.PLX_ROOT.'version" est nécessaire au fonctionnement de Pluxml';
			exit;
		}
		$f = file(PLX_ROOT.'version');
		$this->version = $f['0'];
		
		# Traitement initial
		$this->start = plxUtils::microtime();
		$this->get = plxUtils::getGets();
		
		# On parse le fichier de configuration
		$this->getConfiguration($filename);
		$this->racine = $this->aConf['racine'];
		$this->bypage = $this->aConf['bypage'];
		$this->style = $this->aConf['style'];
		$this->tri = $this->aConf['tri'];
		
		# Traitement sur les répertoires des articles et des commentaires
		$this->plxGlob_arts = & new plxGlob(PLX_ROOT.$this->aConf['racine_articles']);
		$this->plxGlob_coms = & new plxGlob(PLX_ROOT.$this->aConf['racine_commentaires']);
		
		# On récupère les catégories et les pages statiques
		$this->getCategories(PLX_ROOT.$this->aConf['categories']);
		$this->getStatiques(PLX_ROOT.$this->aConf['statiques']);
	}

	/**
	 * Méthode qui parse le fichier de configuration et alimente 
	 * le tableau aConf
	 *
	 * @param	filename	emplacement du fichier XML de configuration
	 * @return	null
	 * @author	Anthony GUÉRIN et Florent MONTHEL
	 **/
	function getConfiguration($filename) {

		# Mise en place du parseur XML
		$data = implode('',file($filename));
		$parser = xml_parser_create(PLX_CHARSET);
		xml_parser_set_option($parser,XML_OPTION_CASE_FOLDING,0);
		xml_parser_set_option($parser,XML_OPTION_SKIP_WHITE,0);
		xml_parse_into_struct($parser,$data,$values,$iTags);
		xml_parser_free($parser);
		# On verifie qu'il existe des tags "parametre"
		if(isset($iTags['parametre'])) {
			# On compte le nombre de tags "parametre"
			$nb = count($iTags['parametre']);
			# On boucle sur $nb
			for($i = 0; $i < $nb; $i++) {
				if(isset($values[ $iTags['parametre'][$i] ]['value'])) # On a une valeur pour ce parametre
					$this->aConf[ $values[ $iTags['parametre'][$i] ]['attributes']['name'] ] = $values[ $iTags['parametre'][$i] ]['value'];
				else # On n'a pas de valeur
					$this->aConf[ $values[ $iTags['parametre'][$i] ]['attributes']['name'] ] = '';
			}
		}
	}

	/**
	 * Méthode qui parse le fichier des catégories et alimente 
	 * le tableau aCats
	 *
	 * @param	filename	emplacement du fichier XML des catégories
	 * @return	null
	 * @author	Anthony GUÉRIN, Florent MONTHEL, Stephane F.
	 **/
	function getCategories($filename) {

		# Mise en place du parseur XML
		$data = implode('',file($filename));
		$parser = xml_parser_create(PLX_CHARSET);
		xml_parser_set_option($parser,XML_OPTION_CASE_FOLDING,0);
		xml_parser_set_option($parser,XML_OPTION_SKIP_WHITE,0);
		xml_parse_into_struct($parser,$data,$values,$iTags);
		xml_parser_free($parser);
		# On verifie qu'il existe des tags "categorie"
		if(isset($iTags['categorie'])) {
			# On compte le nombre de tags "categorie"
			$nb = count($iTags['categorie']);
			# On boucle sur $nb
			for($i = 0; $i < $nb; $i++) {
				# Recuperation du nom de la categorie
				$this->aCats[ $values[ $iTags['categorie'][$i] ]['attributes']['number'] ]['name']
				= $values[ $iTags['categorie'][$i] ]['value'];
				# Recuperation de l'url de la categorie
				$this->aCats[ $values[ $iTags['categorie'][$i] ]['attributes']['number'] ]['url']
				= strtolower($values[ $iTags['categorie'][$i] ]['attributes']['url']);
				# Recuperation du tri de la categorie si besoin est
				if(isset($values[ $iTags['categorie'][$i] ]['attributes']['tri']))
					$this->aCats[ $values[ $iTags['categorie'][$i] ]['attributes']['number'] ]['tri']
					= $values[ $iTags['categorie'][$i] ]['attributes']['tri'];
				else # Tri par defaut
					$this->aCats[ $values[ $iTags['categorie'][$i] ]['attributes']['number'] ]['tri']
					= $this->aConf['tri'];
				# Recuperation du nb d'articles par page de la categorie si besoin est
				if(isset($values[ $iTags['categorie'][$i] ]['attributes']['bypage']))
					$this->aCats[ $values[ $iTags['categorie'][$i] ]['attributes']['number'] ]['bypage']
					= $values[ $iTags['categorie'][$i] ]['attributes']['bypage'];
				else # Nb d'articles par page par defaut
					$array[ $values[ $iTags['categorie'][$i] ]['attributes']['number'] ]['bypage']
					= $this->bypage;
				# Recuperer du nombre d'article de la categorie
				$motif = '/^[0-9]{4}.'.$values[ $iTags['categorie'][$i] ]['attributes']['number'].'.[0-9]{12}.[A-Za-z0-9-]+.xml$/';
				$this->aCats[ $values[ $iTags['categorie'][$i] ]['attributes']['number'] ]['articles']
				= ($this->plxGlob_arts->query($motif))?$this->plxGlob_arts->count:0;
			}
		}
	}

	/**
	 * Méthode qui parse le fichier des pages statiques et alimente 
	 * le tableau aStats
	 *
	 * @param	filename	emplacement du fichier XML des pages statiques
	 * @return	null
	 * @author	Florent MONTHEL
	 **/
	function getStatiques($filename) {

		# Mise en place du parseur XML
		$data = implode('',file($filename));
		$parser = xml_parser_create(PLX_CHARSET);
		xml_parser_set_option($parser,XML_OPTION_CASE_FOLDING,0);
		xml_parser_set_option($parser,XML_OPTION_SKIP_WHITE,0);
		xml_parse_into_struct($parser,$data,$values,$iTags);
		xml_parser_free($parser);
		# On verifie qu'il existe des tags "statique"
		if(isset($iTags['statique'])) {
			# On compte le nombre de tags "statique"
			$nb = count($iTags['statique']);
			# On boucle sur $nb
			for($i = 0; $i < $nb; $i++) {
				# Recuperation du nom de la page statique
				$this->aStats[ $values[ $iTags['statique'][$i] ]['attributes']['number'] ]['name']
				= $values[ $iTags['statique'][$i] ]['value'];
				# Recuperation de l'url de la page statique
				$this->aStats[ $values[ $iTags['statique'][$i] ]['attributes']['number'] ]['url']
				= strtolower($values[ $iTags['statique'][$i] ]['attributes']['url']);
				# Recuperation de l'etat de la page
				$this->aStats[ $values[ $iTags['statique'][$i] ]['attributes']['number'] ]['active']
				= intval($values[ $iTags['statique'][$i] ]['attributes']['active']);
				# On verifie que la page statique existe bien
				$file = PLX_ROOT.$this->aConf['racine_statiques'].$values[ $iTags['statique'][$i] ]['attributes']['number'];
				$file .= '.'.$values[ $iTags['statique'][$i] ]['attributes']['url'].'.php';
				
				if(is_readable($file)) # Le fichier existe
					$this->aStats[ $values[ $iTags['statique'][$i] ]['attributes']['number'] ]['readable'] = 1;
				else # Le fichier est illisible
					$this->aStats[ $values[ $iTags['statique'][$i] ]['attributes']['number'] ]['readable'] = 0;
			}
		}
	}

	/**
	 * Méthode qui effectue une analyse de la situation et détermine 
	 * le mode à appliquer. Cette méthode alimente ensuite les variables 
	 * de classe adéquates
	 *
	 * @param	mode	mode du moteur à appliquer
	 * @param	motif	motif de recherche à appliquer
	 * @param	bypage	pagination (nombre d'articles) à appliquer
	 * @return	null
	 * @author	Anthony GUÉRIN et Florent MONTHEL
	 **/
	function prechauffage($mode = '',$motif = '',$bypage = '') {

		if($mode != '' AND $motif != '') {
			$this->mode = $mode; # Mode
			$this->motif = $motif; # Motif de recherche
			$this->bypage = $bypage; # Nombre d'article par page
		}
		elseif($this->get AND preg_match('/^article([0-9]+)\//',$this->get,$capture)) {
			$this->mode = 'article'; # Mode article
			$this->cible = str_pad($capture[1],4,'0',STR_PAD_LEFT); # On complete sur 4 caracteres
			$this->motif = '/^'.$this->cible.'.([0-9]{3}|home).[0-9]{12}.[a-z0-9-]+.xml$/'; # Motif de recherche
			$this->bypage = NULL; # Pas de pagination pour ce mode bien sur
			if($this->aConf['capcha'] == 1) # On cree notre objet capcha si besoin est
				$this->plxCapcha = & new plxCapcha();
		}
		elseif($this->get AND preg_match('/^categorie([0-9]+)\//',$this->get,$capture)) {
			$this->mode = 'categorie'; # Mode categorie
			$this->cible = str_pad($capture[1],3,'0',STR_PAD_LEFT); # On complete sur 3 caracteres
			$this->motif = '/^[0-9]{4}.'.$this->cible.'.[0-9]{12}.[a-z0-9-]+.xml$/'; # Motif de recherche
			$this->tri = $this->aCats[ $this->cible ]['tri']; # Recuperation du tri des articles
			# On a une pagination particuliere pour la categorie (bypage != 0)
			if($this->aCats[ $this->cible ]['bypage'] > 0)
				$this->bypage = ceil($this->aCats[ $this->cible ]['bypage']);
		}			
		elseif($this->get AND preg_match('/^static([0-9]+)\//',$this->get,$capture)) {
			$this->mode = 'static'; # Mode static
			$this->cible = str_pad($capture[1],3,'0',STR_PAD_LEFT); # On complete sur 3 caracteres			
			$this->bypage = NULL; # Pas de pagination pour ce mode bien sur ;)
		}
		elseif($this->get AND preg_match('/^telechargement\/(.+)$/',$this->get,$capture)) {
			$this->mode = 'telechargement'; # Mode telechargement
			$this->cible = $capture[1];	
			$this->bypage = NULL; # Pas de pagination pour ce mode bien sur ;)
		}
		else {
			$this->mode = 'home';
			# On regarde si on a des articles en mode "home"
			if($this->plxGlob_arts->query('/^[0-9]{4}.home.[0-9]{12}.[a-z0-9-]+.xml$/')) {
				$this->motif = '/^[0-9]{4}.home.[0-9]{12}.[a-z0-9-]+.xml$/';
				$this->bypage = NULL; # Tous les articles sur une page
			} else { # Sinon on recupere tous les articles
				$this->motif = '/^[0-9]{4}.[0-9]{3}.[0-9]{12}.[a-z0-9-]+.xml$/';
			}
		}
	}

	/**
	 * Méthode qui effectue le traitement selon le mode du moteur
	 *
	 * @return	null
	 * @author	Florent MONTHEL
	 **/
	function demarrage() {

		if($this->mode == 'home' OR $this->mode == 'categorie') { 
			$this->getPage(); # Recuperation de la page
			$this->getFiles(); # Recuperation des fichiers
			$this->getArticles(); # Recuperation des articles
			if(!$this->plxGlob_arts->count OR !$this->plxRecord_arts->size) { # Aucun article
				$this->plxErreur = & new plxErreur('Aucun article pour cette page !');
				$this->mode = 'erreur';
			}
		}
		elseif($this->mode == 'article') {
			$this->getFiles(); # Recuperation des fichiers
			$this->getArticles(); # Recuperation des articles
			if(!$this->plxGlob_arts->count OR !$this->plxRecord_arts->size) { # Aucun article
				$this->plxErreur = & new plxErreur('Cet article n\'existe pas ou n\'existe plus !');
				$this->mode = 'erreur';
				return;
			}
			# On a une variable GET['msgcom'];
			if(!empty($_GET['msgcom']))
				$this->message_com = urldecode(plxUtils::unSlash($_GET['msgcom']));
			# On a validé le formulaire commentaire
			if (!empty($_POST) AND $this->plxRecord_arts->f('allow_com') AND $this->aConf['allow_com']) {
				# On récupère le retour de la création
				$retour = $this->newCommentaire($this->cible,plxUtils::unSlash($_POST));
				# Url de l'article
				$url = './?article'.intval($this->plxRecord_arts->f('numero')).'/'.$this->plxRecord_arts->f('url');
				if($retour[0] == 'c') { # Le commentaire a été publié
					header('Location: '.$url.'/#'.$retour);
				} elseif($retour == 'mod') { # Le commentaire en modération
					$msg = 'Le commentaire est en cours de mod&eacute;ration par l\'administrateur de ce site';
					header('Location: '.$url.'/&msgcom='.urlencode($msg).'#form');
				} else {
					header('Location: '.$url.'/&msgcom='.urlencode($retour).'&name='.urlencode(plxUtils::unSlash($_POST['name'])).'&site='.urlencode(plxUtils::unSlash($_POST['site'])).'&mail='.urlencode(plxUtils::unSlash($_POST['mail'])).'&content='.urlencode(plxUtils::unSlash($_POST['content'])).'#form');
				}
				exit;
			}
			# Récupération des commentaires
			$this->getCommentaires('/^'.$this->cible.'.[0-9]{10}-[0-9]+.xml$/');
		}
		elseif($this->mode == 'static') {
			# On va verifier que la page existe vraiment
			if(!isset($this->aStats[ $this->cible ]) OR intval($this->aStats[ $this->cible ]['active']) != 1) {
				$this->plxErreur = & new plxErreur('Cette page n\'existe pas ou n\'existe plus !');
				$this->mode = 'erreur';
			}
			# On va verifier que la page a inclure est lisible
			elseif($this->aStats[ $this->cible ]['readable'] != 1) {
				$this->plxErreur = & new plxErreur('Cette page est actuellement en cours de r&eacute;daction');
				$this->mode = 'erreur';
			}
		}
		elseif($this->mode == 'telechargement') {
			# On va verifier que la page existe vraiment
			if(!$this->sendTelechargement($this->cible)) {
				$this->plxErreur = & new plxErreur('Le document sp&eacute;cifi&eacute; est introuvable');
				$this->mode = 'erreur';
			}
		}
	}

	/**
	 * Méthode qui récupère le numéro de la page active
	 *
	 * @return	null
	 * @author	Anthony GUÉRIN et Florent MONTHEL
	 **/
	function getPage() {
		# On check pour avoir le numero de page
		if(preg_match('/page([0-9]*)/',$this->get,$capture))
			$this->page = $capture[1];
	}

	/**
	 * Méthode qui enregistre dans le tableau aFiles tous les articles 
	 * respectants le motif de recherche et les différents paramètres 
	 *
	 * @return	null
	 * @author	Anthony GUÉRIN et Florent MONTHEL
	 **/
	function getFiles() {

		# On fait notre traitement sur notre tri
		if($this->tri == 'asc')
			$ordre = 'sort';
		else
			$ordre = 'rsort';
		# On recupere nos fichiers (tries) selon le motif et la pagination
		$this->aFiles = $this->plxGlob_arts->query($this->motif,'art',$ordre,$this->bypage*($this->page-1),$this->bypage);
	}

	/**
	 * Méthode qui enregistre dans un objet plxRecord tous les articles
	 * des fichiers du tableau aFiles
	 *
	 * @return	null
	 * @author	Anthony GUÉRIN et Florent MONTHEL
	 **/
	function getArticles() {

		if(is_array($this->aFiles)) { # On a des fichiers
			while(list($k,$v) = each($this->aFiles)) # On parcourt tous les fichiers
				$array[ $k ] = $this->parseArticle(PLX_ROOT.$this->aConf['racine_articles'].$v);
			# On stocke les enregistrements dans un objet plxRecord
			$this->plxRecord_arts = & new plxRecord($array);
		}
	}

	/**
	 * Méthode qui retourne les informations $output en analysant 
	 * le nom du fichier de l'article $filename
	 *
	 * @param	filename	fichier de l'article à traiter
	 * @param	output	information à récupérer
	 * @return	array ou string
	 * @author	Florent MONTHEL
	 **/	
	function artInfoFromFilename($filename,$output) {

		# On effectue notre capture d'informations
		if(preg_match('/([0-9]{4}).([0-9]{3}|home|draft).([0-9]{12}).([a-z0-9-]+).xml$/',$filename,$capture)) {
			if($output == 'all') # On recupere toutes les informations
				return array('artId'=>$capture[1],'catId'=>$capture[2],'artDate'=>$capture[3],'artUrl'=>$capture[4]);
			if($output == 'artId') # Id de l'article
				return $capture[1];
			if($output == 'catId') # Id de la categorie
				return $capture[2];
			if($output == 'artDate') # Date
				return $capture[3];
			if($output == 'artUrl') # Url de l'article
				return $capture[4];
		}
	}

	/**
	 * Méthode qui parse l'article du fichier $filename
	 * 
	 * @param	filename	fichier de l'article à parser
	 * @return	array
	 * @author	Anthony GUÉRIN et Florent MONTHEL
	 **/
	function parseArticle($filename) {

		# Mise en place du parseur XML
		$data = implode('',file($filename));
		$parser = xml_parser_create(PLX_CHARSET);
		xml_parser_set_option($parser,XML_OPTION_CASE_FOLDING,0);
		xml_parser_set_option($parser,XML_OPTION_SKIP_WHITE,0);
		xml_parse_into_struct($parser,$data,$values,$iTags);
		xml_parser_free($parser);
		
		# Recuperation des valeurs de nos champs XML
		$art['title'] = trim($values[ $iTags['title'][0] ]['value']);
		$art['author'] = trim($values[ $iTags['author'][0] ]['value']);
		$art['allow_com'] = trim($values[ $iTags['allow_com'][0] ]['value']);
		$art['chapo'] = (isset($values[ $iTags['chapo'][0] ]['value']))?trim($values[ $iTags['chapo'][0] ]['value']):'';
		$art['content'] = (isset($values[ $iTags['content'][0] ]['value']))?trim($values[ $iTags['content'][0] ]['value']):'';
		
		# Informations obtenues en analysant le nom du fichier
		$art['filename'] = $filename;
		$art['size'] = filesize($filename);
		$tmp = $this->artInfoFromFilename($filename, 'all');
		$art['numero'] = $tmp['artId'];
		$art['categorie'] = $tmp['catId'];
		$art['url'] = $tmp['artUrl'];
		$art['date'] = plxUtils::dateToIso($tmp['artDate'],$this->aConf['delta']);
		
		# On recupere le nombre de commentaires de cet article si besoin est
		if($this->mode != 'article') { # En mode article, on a cette information autrement
			$motif = '/^'.$art['numero'].'.[0-9]{10}.[0-9]+.xml$/';
			$art['nb_com'] = $this->getNbCommentaires($motif);
		}
		
		# On retourne le tableau
		return $art;
	}

	/**
	 * Méthode qui retourne le nombre de commentaires respectants le motif $motif
	 *
	 * @param	motif	motif de recherche des commentaires
	 * @return	integer
	 * @author	Florent MONTHEL
	 **/
	function getNbCommentaires($motif) {

		# On a des resultats
		if($this->plxGlob_coms->query($motif))
			return $this->plxGlob_coms->count;
		else # On a rien
			return 0;
	}

	/**
	 * Méthode qui retourne les informations $output en analysant 
	 * le nom du fichier du commentaire $filename
	 *
	 * @param	filename	fichier du commentaire à traiter
	 * @param	output	information à récupérer
	 * @return	array ou string
	 * @author	Florent MONTHEL
	 **/
	function comInfoFromFilename($filename,$output) {

		# On effectue notre capture d'informations
		if(preg_match('/_?([0-9]{4}).([0-9]{10})-([0-9])+.xml$/',$filename,$capture)) {
			if($output == 'all') # On recupere toutes les informations
				return array('artId'=>$capture[1],'comDate'=>$capture[2],'comId'=>$capture[2].'-'.$capture[3]);
			if($output == 'artId') # Id de l'article
				return $capture[1];
			if($output == 'comDate') # Date
				return $capture[2];
			if($output == 'comId') # Id du commentaire
				return $capture[2].'-'.$capture[3];
		}
	}

	/**
	 * Méthode qui parse le commentaire du fichier $filename
	 *
	 * @param	filename	fichier du commentaire à parser
	 * @return	array
	 * @author	Florent MONTHEL
	 **/
	function parseCommentaire($filename) {

		# Mise en place du parseur XML
		$data = implode('',file($filename));
		$parser = xml_parser_create(PLX_CHARSET);
		xml_parser_set_option($parser,XML_OPTION_CASE_FOLDING,0);
		xml_parser_set_option($parser,XML_OPTION_SKIP_WHITE,0);
		xml_parse_into_struct($parser,$data,$values,$iTags);
		xml_parser_free($parser);
		
		# Recuperation des valeurs de nos champs XML
		$com['author'] = trim($values[ $iTags['author'][0] ]['value']);
		$com['ip'] = trim($values[ $iTags['ip'][0] ]['value']);
		$com['mail'] = (isset($values[ $iTags['mail'][0] ]['value']))?trim($values[ $iTags['mail'][0] ]['value']):'';
		$com['site'] = (isset($values[ $iTags['site'][0] ]['value']))?trim($values[ $iTags['site'][0] ]['value']):'';
		$com['content'] = trim($values[ $iTags['content'][0] ]['value']);
		
		# Informations obtenues en analysant le nom du fichier
		$tmp = $this->comInfoFromFilename($filename, 'all');
		$com['numero'] = $tmp['comId'];
		$com['article'] = $tmp['artId'];
		$com['date'] = plxUtils::timestampToIso($tmp['comDate'],$this->aConf['delta']);
		
		# On retourne le tableau
		return $com;
	}

	/**
	 * Méthode qui enregistre dans un objet plxRecord tous les commentaires 
	 * respectant le motif $motif et la limite $limite
	 *
	 * @param	motif	motif de recherche des commentaires
	 * @param	ordre	ordre du tri : sort ou rsort
	 * @param	start	commencement
	 * @param	limite	nombre de commentaires à retourner
	 * @return	null
	 * @author	Florent MONTHEL
	 **/
	function getCommentaires($motif, $ordre='sort', $start=0, $limite=false) {
		
		# On recupère les fichiers des commentaires
		$aFiles = $this->plxGlob_coms->query($motif,'com',$ordre,$start,$limite);
		if($aFiles) { # On a des fichiers
			while(list($k,$v) = each($aFiles)) # On parcourt tous les fichiers
				$array[ $k ] = $this->parseCommentaire(PLX_ROOT.$this->aConf['racine_commentaires'].$v);
			# On stocke les enregistrements dans un objet plxRecord
			$this->plxRecord_coms = & new plxRecord($array);
		}
	}

	/**
	 * Méthode qui crée un nouveau commentaire pour l'article $artId
	 *
	 * @param	artId	identifiant de l'article en question
	 * @param	content	tableau contenant les valeurs du nouveau commentaire
	 * @return	string
	 * @author	Florent MONTHEL
	 **/
	function newCommentaire($artId,$content) {

		# On verifie que le capcha est correct, si besoin est
		if($this->aConf['capcha'] == 0 OR $content['rep2'] == md5($this->plxCapcha->gds.$content['rep'])) {
			if(!empty($content['name']) AND !empty($content['content'])) { # Les champs obligatoires sont remplis
				$author = htmlspecialchars(trim($content['name']),ENT_QUOTES,PLX_CHARSET);
				$contenu = htmlspecialchars(trim($content['content']),ENT_QUOTES,PLX_CHARSET);
				$date = time();
				# On verifie le mail
				$mail = (plxUtils::checkMail(trim($content['mail'])))?trim($content['mail']):'';
				# On verifie le site
				$site = (plxUtils::checkSite(trim($content['site'])))?trim($content['site']):'';
				# On recupere l'adresse IP du posteur
				$ip = plxUtils::getIp();
				# On genere le nom du fichier selon l'existence ou non d'un fichier du meme nom
				$i = 0;
				do { # On boucle en testant l'existence du fichier
					$i++;
					if($this->aConf['mod_com']) # On modere le commentaire => underscore
						$filename = PLX_ROOT.$this->aConf['racine_commentaires'].'_'.$artId.'.'.$date.'-'.$i.'.xml';
					else # On publie le commentaire directement
						$filename = PLX_ROOT.$this->aConf['racine_commentaires'].$artId.'.'.$date.'-'.$i.'.xml';
				} while(file_exists($filename));
				# On peut creer le commentaire
				if($this->addCommentaire($filename,$author,$ip,$mail,$site,$contenu)) { # Commentaire OK
					if($this->aConf['mod_com']) # En cours de moderation
						return 'mod';
					else # Commentaire publie directement, on retourne son identifiant
						return 'c'.$date.'-'.$i;
				} else { # Erreur lors de la création du commentaire
					return 'Une erreur s\'est produite lors de la publication de ce commentaire';
				}
			} else { # Erreur de remplissage des champs obligatoires
				return 'Merci de remplir tous les champs obligatoires requis';
			}
		} else { # Erreur de verification capcha
			return 'La v&eacute;rification anti-spam a echou&eacute;e';
		}
	}
	
	/**
	 * Méthode qui crée physiquement le fichier XML du commentaire
	 *
	 * @param	filename	fichier du commentaire à créer
	 * @param	author	auteur du commmentaire
	 * @param	ip	adresse IP posteuse du commmentaire
	 * @param	mail	mail de l'auteur du commmentaire
	 * @param	site	site de l'auteur du commmentaire
	 * @param	contenu	contenu du commmentaire
	 * @return	booléen
	 * @author	Anthony GUÉRIN et Florent MONTHEL
	 **/
	function addCommentaire($filename,$author,$ip,$mail,$site,$contenu) {

		# On genere le contenu de notre fichier XML
		$xml = "<?xml version='1.0' encoding='".PLX_CHARSET."'?>\n";
		$xml .= "<comment>\n";
		$xml .= "\t<author><![CDATA[$author]]></author>\n";
		$xml .= "\t<ip>$ip</ip>\n";
		$xml .= "\t<mail><![CDATA[$mail]]></mail>\n";
		$xml .= "\t<site><![CDATA[$site]]></site>\n";
		$xml .= "\t<content><![CDATA[$contenu]]></content>\n";
		$xml .= "</comment>\n";
		# On ecrit ce contenu dans notre fichier XML
		return plxUtils::write($xml,$filename);
	}
	
	/**
	 * Méthode qui lance le téléchargement d'un document
	 *
	 * @param	cible	cible de téléchargement cryptée
	 * @return	booleen
	 * @author	Stephane F. et Florent MONTHEL
	 **/
	function sendTelechargement($cible) {

		# On décrypte le nom du fichier
		$file = PLX_ROOT.$this->aConf['documents'].plxEncrypt::decryptId($cible);
		if(@file_exists($file)) { # On lance le téléchargement
			header('Content-Description: File Transfer');
			header('Content-Type: application/download');
			header('Content-Disposition: attachment; filename='.basename($file));
			header('Content-Transfer-Encoding: binary');
			header('Expires: 0');
			header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
			header('Pragma: no-cache');
			header('Content-Length: '.filesize($file));
			readfile($file);
			return true;
		} else { # On retourne false
			return false;
		}
	}

}
?>