<?php
# ------------------ BEGIN LICENSE BLOCK ------------------
#
# This file is part of Pluxml.
#
# Copyright (c) 2008 Florent MONTHEL and contributors
# Copyright (c) 2006-2008 Anthony GUERIN
# Licensed under the GPL license.
# See http://www.gnu.org/licenses/gpl.html
#
# ------------------- END LICENSE BLOCK -------------------

# Configuration avançée #
define('PLX_ROOT', './');
define('PLX_CORE', PLX_ROOT.'core/');
define('PLX_CONF', PLX_ROOT.'data/configuration/parametres.xml');

# On verifie que Pluxml n'est pas déjà installé
if(file_exists(PLX_CONF)) {
	header('Content-Type: text/plain charset=UTF-8');
	echo 'Pluxml est déjà configuré !';
	exit;
}

# On inclut les librairies nécessaires
include_once(PLX_ROOT.'config.php');
include_once(PLX_CORE.'lib/class.plx.utils.php');
	
# Configuration de base
$f = file(PLX_ROOT.'version');
$version = $f['0'];
$config = array('title'=>'Pluxml', 
				'description'=>'le blog full XML',
				'racine'=>plxUtils::getRacine(), 
				'delta'=>'+00:00', 
				'allow_com'=>1, 
				'mod_com'=>0, 
				'capcha'=>1, 
				'style'=>'defaut', 
				'bypage'=>5,
				'bypage_admin'=>10, 
				'bypage_admin_coms'=>10, 				
				'bypage_feed'=>8, 
				'tri'=>'date-desc',
				'images'=>'data/images/', 
				'documents'=>'data/documents/', 
				'racine_articles'=>'data/articles/',
				'racine_commentaires'=>'data/commentaires/',
				'racine_statiques'=>'data/statiques/',
				'statiques'=>'data/configuration/statiques.xml', 
				'categories'=>'data/configuration/categories.xml', 
				'passwords'=>'data/configuration/passwords.xml'
				);

function install($content, $config) {

	# Echappement des caractères
	$content = plxUtils::unSlash($content);
	# Tableau des clés à mettre sous chaîne cdata
	$aCdata = array('title','description','racine');
	
	# Création du fichier de configuration
	$xml = '<?xml version="1.0" encoding="'.PLX_CHARSET.'"?>'."\n";
	$xml .= '<document>'."\n";
	foreach($config as $k=>$v) {
		if(in_array($k,$aCdata))
			$xml .= "\t<parametre name=\"$k\"><![CDATA[".$v."]]></parametre>\n";
		else
			$xml .= "\t<parametre name=\"$k\">".$v."</parametre>\n";
	}
	$xml .= '</document>';
	plxUtils::write($xml,PLX_CONF);
	
	# Création du fichier de mot de passe
	$xml = '<?xml version="1.0" encoding="'.PLX_CHARSET.'"?>'."\n";
	$xml .= '<document>'."\n";
	$xml .= "\t".'<user login="'.trim($content['name']).'" >'.md5(trim($content['pwd'])).'</user>'."\n";
	$xml .= '</document>';
	plxUtils::write($xml,PLX_ROOT.$config['passwords']);
	
	# Création du fichier des categories
	$xml = '<?xml version="1.0" encoding="'.PLX_CHARSET.'"?>';
	$xml .= '<document>'."\n";
	$xml .= "\t".'<categorie number="001" tri="'.$config['tri'].'" bypage="'.$config['bypage'].'" url="rubrique-1"><![CDATA[Rubrique 1]]></categorie>'."\n";
	$xml .= '</document>';
	plxUtils::write($xml,PLX_ROOT.$config['categories']);
	
	# Création du fichier des pages statiques
	$xml = '<?xml version="1.0" encoding="'.PLX_CHARSET.'"?>'."\n";
	$xml .= '<document>'."\n";
	$xml .= "\t".'<statique number="001" active="1" url="statique-1"><![CDATA[Statique 1]]></statique>'."\n";
	$xml .= '</document>';
	plxUtils::write($xml,PLX_ROOT.$config['statiques']);
	$cs = '<p><?php echo \'Ma premi&egrave;re page statique !\'; ?></p>';
	plxUtils::write($cs,PLX_ROOT.$config['racine_statiques'].'001.statique-1.php');
	
	# Création du premier article
	$xml = '<?xml version="1.0" encoding="'.PLX_CHARSET.'"?>'."\n";
	$xml .= '<document>
	<infopost>
		<title><![CDATA[Premier article]]></title>
		<author><![CDATA['.trim($content['name']).']]></author>
		<allow_com>1</allow_com>
	</infopost>
	<chapo>
		<![CDATA[]]>
	</chapo>
	<content>
		<![CDATA[<p>Ceci est un article cr&eacute;&eacute; lors de l\'installation. Editez-le depuis la zone d\'administration.</p>]]>
	</content>
</document>';
	plxUtils::write($xml,PLX_ROOT.$config['racine_articles'].'0001.001.'.date('YmdHi').'.premier-article.xml');
}

if (!empty($_POST['name']) AND !empty($_POST['pwd']) AND $_POST['pwd'] == $_POST['pwd2'] ) {
	install($_POST, $config);
	header('Location: '.plxUtils::getRacine());
	exit;
}
?>
<?php header ('Content-Type: text/html; charset='.PLX_CHARSET); ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="fr" lang="fr">
<head>
<title>Pluxml <?php echo $version; ?> - Installation</title>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo strtolower(PLX_CHARSET) ?>" />
<link rel="stylesheet" type="text/css" href="core/admin/admin.css" media="screen" />
</head>

<body>
<h2>Installation de Pluxml</h2>
<ul>
	<li>Version : <?php echo $version; ?></li>
	<li><strong><?php plxUtils::testWrite(dirname(PLX_CONF)); ?></strong></li>
	<li><strong><?php plxUtils::testWrite(PLX_ROOT.$config['racine_articles']); ?></strong></li>
	<li><strong><?php plxUtils::testWrite(PLX_ROOT.$config['racine_commentaires']); ?></strong></li>
	<li><strong><?php plxUtils::testWrite(PLX_ROOT.$config['racine_statiques']); ?></strong></li>
	<li>Version de php : <?php echo phpversion(); ?></li>
	<li>Etat des "magic quotes" : <?php echo get_magic_quotes_gpc(); ?></li>
</ul>
<form action="install.php" method="post">
	<fieldset>
		<p class="field"><label>Nom du r&eacute;dacteur&nbsp;:</label></p>
		<?php plxUtils::printInput('name', '', 'text', '20-255') ?>
		<p class="field"><label>Mot de passe du r&eacute;dacteur&nbsp;:</label></p>
		<?php plxUtils::printInput('pwd', '', 'password', '20-255') ?>
		<p class="field"><label>Confirmation du mot de passe&nbsp;:</label></p>
		<?php plxUtils::printInput('pwd2', '', 'password', '20-255') ?>
		<?php plxUtils::printInput('version', $version, 'hidden') ?>
		<p><input type="submit" value="Installer" /></p>
	</fieldset>
</form>
</body>
</html>